@@ -8,11 +8,11 @@ Licensed under the MIT license.
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 1
-SUB_MINOR_VERSION = 1
+SUB_MINOR_VERSION = 3
 __version__ = '{}.{}.{}'.format(
     MAJOR_VERSION, MINOR_VERSION, SUB_MINOR_VERSION)
 
-API_URL = 'https://app-api.8slp.net/v1'
+API_URL = 'https://client-api.8slp.net/v1'
 
 DEFAULT_TIMEOUT = 60
 
@@ -22,5 +22,5 @@ DEFAULT_HEADERS = {
     'user-agent': "okhttp/3.6.0",
     'accept-encoding': "gzip",
     'accept': "*/*",
-    'authority': "app-api.8slp.net",
+    'authority': "client-api.8slp.net",
     }
